import os
import pandas as pd
import pandas_ta as ta
import matplotlib.pyplot as plt
from termcolor import colored


DB_PATH = r'./eqs/'
COL_DATE = '<DATE>'
COL_CLOSE = '<CLOSE>'
RSI_THRESHOLD = 50
RSI_WINDOW = 14
 

# Get all files in a given directory and its directories
for root, dirs, files in os.walk(DB_PATH, topdown=False):
    print("1st for {}".format(root))
    for name in files:
        fp = os.path.join(root, name)
        df = pd.read_csv(fp)
        # Convert data in string to date
        df[COL_DATE] = df[COL_DATE].apply(pd.to_datetime, format="%Y%m%d")
        # Restrict the data which is to be plotted to several months
        df = df[df[COL_DATE] >= '2021-01-01']
        # Make a date an index of the frame
        df.set_index(COL_DATE, inplace=True)
        # For faster computation take only the last RSI_WINDOW+1 data points
        df_test = df.iloc[-(RSI_WINDOW+1):].copy()
        rsi = df_test.ta.rsi(close=COL_CLOSE)
        if rsi[-1] > RSI_THRESHOLD:
            print(colored("{eq} RSI: {val}".
                  format(eq=fp, val=round(rsi[-1])), "red"))
            continue
        print(colored("{eq} RSI: {val}".
              format(eq=fp, val=round(rsi[-1])), "green"))
        # Compute again the indicator for a positively selected equity but this
        # time for all data points
        rsi = df.ta.rsi(close=COL_CLOSE)
        # Make plots for the filtered equities
        f, axs = plt.subplots(nrows=2, ncols=1)
        # Plot equity
        axs[0].plot(df[COL_CLOSE])
        # Plot indicator
        axs[1].plot(rsi)
        # Align labels on the x-axis
        f.autofmt_xdate()
        axs[0].grid(True)
        axs[0].set_ylabel('Price')
        axs[1].grid(True)
        axs[1].set_ylabel('RSI value')
        # Show plots
        # plt.show()
        # Save plots for later examination or show it
        fname, ext = os.path.splitext(name)
        plt.savefig(fname)
        plt.close()
